@@ -20,8 +20,8 @@ class NotificationStack(Stack):
             # the properties below are optional
             bundle_id="bundleId",
             # certificate="certificate",
-            default_authentication_method="certificate",
-            enabled=False,
+            # default_authentication_method="certificate",
+            # enabled=False,
             # private_key="privateKey",
             # team_id="teamId",
             # token_key="tokenKey",
